import 'dart:math';

import 'package:feed_plugin/models/media.dart';
import 'package:feed_plugin/models/poll_option_model.dart';
import 'package:feed_plugin/models/poll_vote_model.dart';
import 'package:feed_plugin/models/story.dart';
import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/pages/share_story.dart';
import 'package:feed_plugin/pages/test2.dart';
import 'package:feed_plugin/pages/user_posts.dart';
import 'package:feed_plugin/repo/feed_repository.dart';
import 'package:feed_plugin/service/http_service.dart';
import 'package:feed_plugin/widgets/story/story.dart';
import 'package:feed_plugin/widgets/story/story_button.dart';
import 'package:flutter_mobile_carousel/carousel.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:flutter/material.dart';
import 'dart:async';
import 'package:intl/intl.dart';
import 'package:datetime_picker_formfield/datetime_picker_formfield.dart';
import 'package:feed_plugin/models/post_model.dart';
import 'package:feed_plugin/pages/my_feed.dart';
import 'package:feed_plugin/pages/partner_feed.dart';
import 'package:feed_plugin/pages/share_post_page.dart';
import 'package:feed_plugin/widgets/loadingButtonIndicator.dart';
import 'package:feed_plugin/widgets/post.dart';
import 'package:feed_plugin/widgets/default_profile_img.dart';
import 'package:inview_notifier_list/inview_notifier_list.dart';
import 'package:pusher_websocket_flutter/pusher.dart';
import 'dart:convert';
import '../environment_config.dart';
import 'package:empty_widget/empty_widget.dart';

import '../test.dart';

final lastDate = new DateTime(
  DateTime.now().year - 10,
  DateTime.now().month,
);

String selectedValue = lastDate.toString();
String date;

class HomePage extends StatefulWidget {
  const HomePage(
      {Key key,
      this.token,
      this.firstName,
      this.lastName,
      this.about,
      this.profileImg,
      this.partnerName,
      this.partnerProfileImg,
      this.partnerMedia,
      this.loc})
      : super(key: key);

  final String token;
  final String firstName;
  final String lastName;
  final String about;
  final String profileImg;
  final String partnerName;
  final String partnerProfileImg;
  final partnerMedia;
  final loc;

  @override
  _HomePageState createState() => _HomePageState();
}

class _HomePageState extends State<HomePage>
    with SingleTickerProviderStateMixin {
  final int increment = 1;

  bool isLoadingVertical = false;

  List<PostModel> postsList = [];

  List<PostModel> postsListFilter = [];

  UserModel currentUser;

  bool newPostFlag = false;

  Channel _channel;

  ScrollController _scrollController = new ScrollController();

  double defaultScreenWidth = 375.0;

  double defaultScreenHeight = 812.0;

  final int likeId = 1;

  final int dislikeId = 3;

  final int saveId = 2;

  bool flagFilter;

  int count;

  HttpService httpService;

  FeedRepository feedRepository;

  List<FeedPost> list;

  List<UserModel> userList = [];

  List<Widget> usersWidget = [];

  List<PollOptionModel> pollOptionsList = [];

  List<PostModel> pollPostsList = [];

  List<PostModel> favoritePostsList = [];

  TabController _controller;

  bool isMyFeedPage = false;

  List<PostModel> myPosts;

  List<PollVoteModel> pollVotesList = [];

  List<PollVoteModel> pollVotesListToQuestion = [];

  StoryModel currentUserStory;

  @override
  void initState() {
    _controller = new TabController(length: 2, vsync: this);
    httpService = HttpService("gogog");
    feedRepository = FeedRepository(httpService);
    flagFilter = false;
    count = 0;
    initPusher();
    getCurrentUser();
    getPosts();
    // randomUsers();
    super.initState();
  }

  dispose() {
    _scrollController.dispose();
    super.dispose();
  }

  Future<void> initPusher() async {
    try {
      await Pusher.init(
          EnvironmentConfig.PUSHER_ENV, PusherOptions(cluster: 'ap2'));
    } catch (e) {
      print(e);
    }

    Pusher.connect(onConnectionStateChange: (val) {}, onError: (err) {});

    _channel = await Pusher.subscribe('post');
    _channel.bind(
      'create_post',
      (onEvent) async {
        List<dynamic> newPost = json.decode(onEvent.data);
        List<PostModel> postsList =
            newPost.map((i) => PostModel.fromJson(i)).toList();
        List<PostModel> posts1 = postsListFilter.reversed.toList();
        if (postsList[0].pollQuestion != null) {
          await feedRepository.getAllOptions().then((value) async => {
                setState(() {
                  pollOptionsList = value;
                })
              });
        }

        if (mounted) {
          this.setState(() {
            posts1.add(postsList[0]);
            postsListFilter = posts1.reversed.toList();
            postsList = posts1.reversed.toList();
            newPostFlag = true;
            pollPostsList =
                postsListFilter.where((p) => p.pollQuestion != null).toList();
          });
        }
      },
    );

    _channel.bind(
      'remove_post',
      (onEvent) {
        int postId = int.parse(onEvent.data);
        List<PostModel> posts = [];
        postsListFilter.forEach(
          (post) {
            if (post.id != postId) {
              posts.add(post);
            }
          },
        );
        if (mounted) {
          this.setState(
            () {
              postsListFilter = posts;
              postsList = posts;
            },
          );
        }
      },
    );
  }

  getStories() async {
    // Random rnd = new Random();

    // int min = 0, max = 29;
    // int skip = min + rnd.nextInt(max - min);
    List<Widget> wl = [];
    List<PostModel> userPosts = [];

    // await feedRepository.getUsersRandom(skip).then((users) => {
    //       users.forEach((u) {
    //         var userClip = u.profileImg != null &&
    //                 u.profileImg != "" &&
    //                 u.profileImg != "null"
    List<UserModel> users;
    Widget storyButton;
    await feedRepository.getStoriesToday().then((stories) => {
          users = [],
          stories.forEach((s) {
            if (s.user.id == currentUser?.id) {
              setState(() {
                currentUserStory = s;
              });
            }
            users.add(s.user);
            var userClip = s.user.profileImg != null &&
                    s.user.profileImg != "" &&
                    s.user.profileImg != "null"
                ? GestureDetector(
                    onTap: () => {
                      userPosts = postsListFilter
                          .where((p) => p.user.id == s.user.id)
                          .toList(),
                      Navigator.push(
                        context,
                        MaterialPageRoute(
                          builder: (context) => StoryPage(
                            images: s.attachedUrl.split("*"),
                            user: s.user,
                            text: s.text.split("K*K"),
                          ),
                          //  UserPost(
                          //   userData: u,
                          //   currentUser: currentUser,
                          //   userPosts: userPosts,
                          //   pollOptionsList: pollOptionsList,
                          //   pollVotesList: pollVotesList,
                          //   loc: this.widget.loc,
                          // ),
                        ),
                      )
                    },
                    child: Container(
                      padding: const EdgeInsets.all(4.0),
                      margin: const EdgeInsets.all(4.0),
                      height: ScreenUtil().setHeight(5),
                      decoration: new BoxDecoration(
                        shape: BoxShape.circle,
                        border: new Border.all(
                          color: Colors.grey,
                          width: 0.6,
                        ),
                      ),
                      child: ClipOval(
                        child: Image.network(
                          s.user.profileImg,
                          fit: BoxFit.cover,
                        ),
                      ),
                    ),
                  )
                : GestureDetector(
                    onTap: () => {
                          userPosts = postsListFilter
                              .where((p) => p.user.id == s.user.id)
                              .toList(),
                          Navigator.push(
                            context,
                            MaterialPageRoute(
                                builder: (context) => StoryPage(
                                      user: s.user,
                                      images: s.attachedUrl.split("*"),
                                      text: s.text.split("K*K"),
                                    )
                                // UserPost(
                                //   userData: u,
                                //   currentUser: currentUser,
                                //   userPosts: userPosts,
                                //   pollOptionsList: pollOptionsList,
                                //   pollVotesList: pollVotesList,
                                //   loc: this.widget.loc,
                                // ),
                                ),
                          )
                        },
                    child: Container(
                        padding: const EdgeInsets.all(4.0),
                        margin: const EdgeInsets.all(4.0),
                        height: ScreenUtil().setHeight(5),
                        decoration: new BoxDecoration(
                          shape: BoxShape.circle,
                          border: new Border.all(
                            color: Colors.grey,
                            width: 0.6,
                          ),
                        ),
                        child: DefaultProfileImg(
                            firstName: s.user.firstName,
                            lastName: s.user.lastName)));

            wl.add(userClip);
          }),
          storyButton = GestureDetector(
              onTap: () async {
                var res = await Navigator.push(
                    context,
                    MaterialPageRoute(
                        builder: (context) => ShareStoryPage(
                              currentUser: currentUser,
                              loc: widget.loc,
                              currentUserStory: currentUserStory,
                            )));
                getStories();
              },
              child: StoryButtonPage(
                  currentUser: currentUser,
                  loc: widget.loc,
                  currentUserStory: currentUserStory)),
          wl.insert(0, storyButton),
          setState(() => {
                userList = users,
                usersWidget = wl,
              }),
        });
  }

  Future<List<PostModel>> getPosts() async {
    List<PostModel> posts = [];
    // StoryModel s = await feedRepository.removeStory(26);
    // bool p = await feedRepository.removePost(1257);
    // bool r = await feedRepository.removeReport(1201);
    posts = await loadPosts();
    return posts;
  }

  Future<UserModel> getCurrentUser() async {
    await feedRepository
        .authenticateUser(widget.firstName, widget.lastName, widget.about,
            widget.profileImg, widget.token, null)
        .then((user) async => {
              setState(
                () {
                  currentUser = user;
                },
              ),
              // await getStories()
            });
    return currentUser;
  }

  void startTimer(int num) {
    count = num;
    Timer.periodic(
      Duration(seconds: 1),
      (_timer) {
        if (count > 0) {
          count--;
        } else {
          _timer.cancel();
          setState(
            () {
              newPostFlag = false;
            },
          );
        }
      },
    );
  }

  bool filter({@required DateTime createdAt, @required String selectedDate}) {
    DateTime fromDate = createdAt;
    DateTime toDate = new DateFormat("yyyy-MM-dd hh:mm:ss").parse(selectedDate);
    if (fromDate.isAfter(toDate) || toDate == fromDate) {
      return true;
    }
    return false;
  }

  bool filterByDay(
      {@required DateTime createdAt, @required String selectedDate}) {
    DateTime theDate =
        new DateFormat("yyyy-MM-dd hh:mm:ss").parse(selectedDate);
    setState(
      () {
        flagFilter = true;
      },
    );
    if (theDate.day == createdAt.day &&
        theDate.month == createdAt.month &&
        theDate.year == createdAt.year) {
      return true;
    }
    return false;
  }

  void getPostsByFilter() {
    List<PostModel> postsListTemp = [];

    for (var i = 0; i < postsList.length; i++) {
      if (filterByDay(
          createdAt: postsList[i].createdAt, selectedDate: selectedValue)) {
        postsListTemp.add(postsList[i]);
      }
    }
    setState(
      () {
        postsListFilter = postsListTemp;
      },
    );
  }

  List<PostModel> posts = [];

  Future<List<PostModel>> loadPosts() async {
    postsListFilter = [];
    await feedRepository.getAllOptions().then((value) async => {
          setState(() {
            pollOptionsList = value;
          })
        });
    await feedRepository.getAllVotes().then((value) async => {
          setState(() {
            pollVotesList = value;
          })
        });
    await getStories();
    await feedRepository.loadPosts().then((value) async => {
          setState(() {
            posts = value;
            postsListFilter = posts.reversed.toList();
            postsList = posts.reversed.toList();
            pollPostsList =
                postsListFilter.where((p) => p.pollQuestion != null).toList();
            myPosts = postsListFilter
                .where((p) => p.user.id == currentUser.id)
                .toList();
          }),
        });
    return postsListFilter;
  }

  Future refreshData() async {
    await getPosts();
    return;
  }

  @override
  void didChangeDependencies() {
    // TODO: implement didChangeDependencies
    getStories();
    super.didChangeDependencies();
  }

  @override
  Widget build(BuildContext context) {
    return ScreenUtilInit(
        designSize: Size(375.0, 812.0),
        allowFontScaling: false,
        builder: () => Scaffold(
              appBar: PreferredSize(
                preferredSize: Size.fromHeight(70.0),
                child: AppBar(
                  automaticallyImplyLeading: false,
                  backgroundColor: Color(0xFF083356),
                  actions: <Widget>[
                    Container(
                      child: this.currentUser != null
                          ? GestureDetector(
                              onTap: () {
                                Navigator.pop(context);
                              },
                              child: GestureDetector(
                                onTap: () {
                                  Media media = Media.fromJson(
                                      jsonDecode(widget.partnerMedia));
                                  Navigator.push(
                                    context,
                                    MaterialPageRoute(
                                      builder: (context) => PartnerFeedPage(
                                        loc: this.widget.loc,
                                        currentUser: this.currentUser,
                                        saveId: saveId,
                                        likeId: likeId,
                                        dislikeId: dislikeId,
                                        profileImg: widget.partnerProfileImg,
                                        firstName: widget.partnerName,
                                        media: media,
                                        pollOptionsList: pollOptionsList,
                                        pollVotesList: pollVotesList,
                                      ),
                                    ),
                                  );
                                },
                                child: Padding(
                                  padding: EdgeInsets.only(
                                      right: ScreenUtil().setWidth(10)),
                                  child: Container(
                                    alignment: Alignment.bottomRight,
                                    child: this.widget.partnerProfileImg ==
                                                null ||
                                            this.widget.partnerProfileImg ==
                                                "" ||
                                            this.widget.partnerProfileImg ==
                                                "null"
                                        ? DefaultProfileImg(
                                            firstName: this.widget.partnerName,
                                          )
                                        : ClipOval(
                                            child: Image.network(
                                              this.widget.partnerProfileImg,
                                              width: ScreenUtil().setWidth(40),
                                              height: ScreenUtil().setWidth(40),
                                              fit: BoxFit.cover,
                                            ),
                                          ),
                                  ),
                                ),
                              ),
                            )
                          : Padding(
                              padding: EdgeInsets.only(
                                right: ScreenUtil().setWidth(10),
                              ),
                              child: Container(),
                            ),
                    ),
                  ],
                  title: Row(
                    children: [
                      this.currentUser != null
                          ? GestureDetector(
                              onTap: () async {
                                List<PostModel> myPosts = postsListFilter
                                    .where((p) => p.user.id == currentUser.id)
                                    .toList();
                                await Navigator.push(
                                  context,
                                  MaterialPageRoute(
                                    builder: (context) => MyFeedPage(
                                      currentUser: this.currentUser,
                                      saveId: saveId,
                                      likeId: likeId,
                                      dislikeId: dislikeId,
                                      postsList1: myPosts,
                                      pollOptionsList: pollOptionsList,
                                      // pollVotesList: pollVotesList,
                                      loc: this.widget.loc,
                                    ),
                                  ),
                                ).then((value) async => {
                                      await loadPosts(),
                                    });
                              },
                              child: Padding(
                                padding: EdgeInsets.only(
                                    top: ScreenUtil().setWidth(12)),
                                child: Container(
                                  alignment: Alignment.centerLeft,
                                  child: this.currentUser.profileImg != null &&
                                          this.currentUser.profileImg != "" &&
                                          this.currentUser.profileImg != "null"
                                      ? ClipOval(
                                          child: Image.network(
                                            this.currentUser.profileImg,
                                            width: ScreenUtil().setWidth(38),
                                            height: ScreenUtil().setWidth(39),
                                            fit: BoxFit.cover,
                                          ),
                                        )
                                      : DefaultProfileImg(
                                          firstName: this.widget.firstName,
                                          lastName: this.widget.lastName),
                                ),
                              ),
                            )
                          : Container(),
                      Padding(
                        padding: EdgeInsets.only(
                          left: ScreenUtil().setWidth(50),
                          top: ScreenUtil().setWidth(10),
                        ),
                        child: Text(
                          this.widget.loc.translate('Feed'),
                          style: TextStyle(color: Colors.white),
                        ),
                      ),
                    ],
                  ),
                ),
              ),
              body: postsListFilter.length < 1 && flagFilter
                  ? GestureDetector(
                      onTap: () {
                        setState(
                          () {
                            postsListFilter = postsList;
                            flagFilter = false;
                          },
                        );
                      },
                      child: Center(
                        child: EmptyWidget(
                          title: this.widget.loc.translate('No Data Found'),
                          subTitle: this
                              .widget
                              .loc
                              .translate('Click here to see all posts'),
                          packageImage: PackageImage.Image_3,
                          titleTextStyle: Theme.of(context)
                              .typography
                              .dense
                              .headline4
                              .copyWith(color: Color(0xff9da9c7)),
                          subtitleTextStyle: Theme.of(context)
                              .typography
                              .dense
                              .bodyText1
                              .copyWith(
                                color: Color(0xffabb8d6),
                              ),
                        ),
                      ),
                    )
                  : postsListFilter.length < 1 && !flagFilter
                      ? Center(child: LoadingIndicatorDark())
                      : Column(
                          crossAxisAlignment: CrossAxisAlignment.stretch,
                          children: [
                            if (newPostFlag == true) _newPostButton(),
                            _buildDateField(),
                            Expanded(
                              child: this.currentUser != null
                                  ? Stack(
                                      children: [
                                        RefreshIndicator(
                                            triggerMode:
                                                RefreshIndicatorTriggerMode
                                                    .anywhere,
                                            onRefresh: () => getPosts(),
                                            child:
                                                // ListView(
                                                // controller: _scrollController,
                                                // children: [
                                                InViewNotifierList(
                                              controller: _scrollController,
                                              // addAutomaticKeepAlives: true,
                                              // contextCacheCount: 20,
                                              scrollDirection: Axis.vertical,
                                              initialInViewIds: ['0'],
                                              isInViewPortCondition: (double
                                                      deltaTop,
                                                  double deltaBottom,
                                                  double viewPortDimension) {
                                                return deltaTop <
                                                        (0.1 *
                                                            viewPortDimension) &&
                                                    deltaBottom >
                                                        (0.8 *
                                                            viewPortDimension);
                                              },
                                              itemCount:
                                                  this.postsListFilter.length +
                                                      1,
                                              builder: (BuildContext context,
                                                  int index) {
                                                return Container(
                                                    color: Color(0xffE8ECEF),
                                                    //   width: double.infinity,
                                                    //   // height: 300.0,
                                                    //   alignment: Alignment.center,
                                                    //   margin: EdgeInsets.symmetric(
                                                    //       vertical: 5.0),
                                                    child: LayoutBuilder(
                                                      builder:
                                                          (BuildContext context,
                                                              BoxConstraints
                                                                  constraints) {
                                                        return InViewNotifierWidget(
                                                          id: '$index',
                                                          builder: (BuildContext
                                                                  context,
                                                              bool isInView,
                                                              Widget child) {
                                                            if (index == 0) {
                                                              return Container(
                                                                margin: EdgeInsets.only(
                                                                    bottom: ScreenUtil()
                                                                        .setHeight(
                                                                            8)),
                                                                height: ScreenUtil()
                                                                    .setHeight(
                                                                        105),
                                                                color: Colors
                                                                    .white,
                                                                child: Column(
                                                                  mainAxisAlignment:
                                                                      MainAxisAlignment
                                                                          .start,
                                                                  crossAxisAlignment:
                                                                      CrossAxisAlignment
                                                                          .start,
                                                                  children: [
                                                                    Container(
                                                                      margin: EdgeInsets.only(
                                                                          bottom: ScreenUtil().setHeight(
                                                                              5),
                                                                          top: ScreenUtil().setHeight(
                                                                              10),
                                                                          left:
                                                                              ScreenUtil().setHeight(10)),
                                                                      child:
                                                                          Text(
                                                                        widget
                                                                            .loc
                                                                            .translate("Story"),
                                                                        style: TextStyle(
                                                                            fontSize:
                                                                                ScreenUtil().setSp(14),
                                                                            fontWeight: FontWeight.w600),
                                                                      ),
                                                                    ),
                                                                    Carousel(
                                                                      rowCount:
                                                                          6,
                                                                      children:
                                                                          usersWidget,
                                                                    )
                                                                  ],
                                                                ),
                                                              );
                                                            }
                                                            List<PollOptionModel>
                                                                pollOptionsListToPost;
                                                            PostModel post =
                                                                this.postsListFilter[
                                                                    index - 1];
                                                            List<
                                                                String> images = postsListFilter[index -
                                                                                1]
                                                                            .attachedUrl !=
                                                                        null &&
                                                                    postsListFilter[index -
                                                                                1]
                                                                            .attachedUrl !=
                                                                        "null"
                                                                ? this
                                                                    .postsListFilter[
                                                                        index -
                                                                            1]
                                                                    .attachedUrl
                                                                    .split("*")
                                                                : [];
                                                            if (post.pollQuestion !=
                                                                null) {
                                                              pollOptionsListToPost =
                                                                  [];
                                                              pollOptionsListToPost = pollOptionsList
                                                                  .where((p) =>
                                                                      p.pollQuestion
                                                                          .id ==
                                                                      post.pollQuestion
                                                                          .id)
                                                                  .toList();

                                                              pollVotesListToQuestion =
                                                                  [];
                                                              pollVotesListToQuestion = pollVotesList
                                                                  .where((p) =>
                                                                      p
                                                                          .pollOption
                                                                          .pollQuestion
                                                                          .id ==
                                                                      post.pollQuestion
                                                                          .id)
                                                                  .toList();
                                                            }
                                                            return FeedPost(
                                                              key: Key("F" +
                                                                  post.id
                                                                      .toString()),
                                                              postData: post,
                                                              currentUser: this
                                                                  .currentUser,
                                                              images: images,
                                                              likeId: likeId,
                                                              dislikeId:
                                                                  dislikeId,
                                                              saveId: saveId,
                                                              commentsLength: 0,
                                                              postsList: this
                                                                  .postsList,
                                                              pollOptionsList:
                                                                  pollOptionsListToPost,
                                                              generalPollOptionsList:
                                                                  pollOptionsList,
                                                              pollVotesList:
                                                                  pollVotesListToQuestion,
                                                              loc: this
                                                                  .widget
                                                                  .loc,
                                                              play: isInView,
                                                            );
                                                          },
                                                        );
                                                      },
                                                    ));
                                              },
                                            )

                                            //     ListView.separated(
                                            //   // shrinkWrap: true,
                                            //   // cacheExtent: 1,
                                            //   // physics:
                                            //   //     NeverScrollableScrollPhysics(),
                                            //   itemCount: this.postsList.length + 1,
                                            //   itemBuilder:
                                            //       (BuildContext context, int index) {
                                            //     if (index == 0) {
                                            //       return Container(
                                            //         margin: EdgeInsets.only(
                                            //             bottom:
                                            //                 ScreenUtil().setHeight(10)),
                                            //         height: ScreenUtil().setHeight(120),
                                            //         color: Colors.white,
                                            //         child: Column(
                                            //           mainAxisAlignment:
                                            //               MainAxisAlignment.start,
                                            //           crossAxisAlignment:
                                            //               CrossAxisAlignment.start,
                                            //           children: [
                                            //             Container(
                                            //               margin: EdgeInsets.only(
                                            //                   bottom: ScreenUtil()
                                            //                       .setHeight(12),
                                            //                   top: ScreenUtil()
                                            //                       .setHeight(10),
                                            //                   left: ScreenUtil()
                                            //                       .setHeight(10)),
                                            //               child: Text(
                                            //                 "You might also like‏:",
                                            //                 style: TextStyle(
                                            //                     fontSize: ScreenUtil()
                                            //                         .setSp(14),
                                            //                     fontWeight:
                                            //                         FontWeight.bold),
                                            //               ),
                                            //             ),
                                            //             Carousel(
                                            //               rowCount: 6,
                                            //               children: usersWidget,
                                            //             )
                                            //           ],
                                            //         ),
                                            //       );
                                            //     }

                                            //     List<PollOptionModel>
                                            //         pollOptionsListToPost;
                                            //     PostModel post =
                                            //         this.postsList[index - 1];
                                            //     List<String> images = this
                                            //         .postsList[index - 1]
                                            //         .attachedUrl
                                            //         .split("*");
                                            //     if (post.pollQuestion != null) {
                                            //       pollOptionsListToPost = [];
                                            //       pollOptionsListToPost =
                                            //           pollOptionsList
                                            //               .where((p) =>
                                            //                   p.pollQuestion.id ==
                                            //                   post.pollQuestion.id)
                                            //               .toList();
                                            //     }

                                            //     return FeedPost(
                                            //       key: Key("F" + post.id.toString()),
                                            //       postData: post,
                                            //       currentUser: this.currentUser,
                                            //       images: images,
                                            //       likeId: likeId,
                                            //       dislikeId: dislikeId,
                                            //       saveId: saveId,
                                            //       commentsLength: 0,
                                            //       postsList: this.postsList,
                                            //       pollOptionsList:
                                            //           pollOptionsListToPost,
                                            //       generalPollOptionsList:
                                            //           pollOptionsList,
                                            //       loc: this.widget.loc,
                                            //     );
                                            //   },
                                            //   separatorBuilder:
                                            //       (BuildContext context, int index) =>
                                            //           const Divider(),
                                            // )
                                            // ])
                                            ),
                                        Align(
                                          alignment: Alignment(0.8, 0.85),
                                          child: Container(
                                            decoration: BoxDecoration(
                                              shape: BoxShape.circle,
                                              boxShadow: [
                                                BoxShadow(
                                                  color: Colors.grey,
                                                  blurRadius: 5.0,
                                                  spreadRadius: 1.0,
                                                )
                                              ],
                                            ),
                                            child: ClipOval(
                                              child: Material(
                                                color: Color(0xFF3DD598),
                                                child: InkWell(
                                                  splashColor:
                                                      Color(0xFFFCA64F),
                                                  child: SizedBox(
                                                    width: 70,
                                                    height: 70,
                                                    child: Icon(Icons.add,
                                                        size: 50.0,
                                                        color: Colors.white),
                                                  ),
                                                  onTap: () {
                                                    Navigator.push(
                                                      context,
                                                      MaterialPageRoute(
                                                          builder: (context) =>
                                                              SharePostPage(
                                                                  currentUser: this
                                                                      .currentUser,
                                                                  loc: this
                                                                      .widget
                                                                      .loc)),
                                                    );
                                                  },
                                                ),
                                              ),
                                            ),
                                          ),
                                        )
                                      ],
                                    )
                                  : Container(),
                            ),
                          ],
                        ),
            ));
  }

  _newPostButton() {
    startTimer(7);
    return Column(
      children: [
        Container(
          decoration: BoxDecoration(
            border: Border(
              bottom: BorderSide(
                width: 15,
                color: Color(0xffE8ECEF),
              ),
            ),
          ),
        ),
        Container(
          color: Colors.white,
          height: ScreenUtil().setHeight(64),
          width: ScreenUtil().screenWidth,
          alignment: Alignment.center,
          child: SizedBox(
            height: ScreenUtil().setHeight(50),
            width: ScreenUtil().setWidth(280),
            child: Container(
              decoration: ShapeDecoration(
                color: Color(0xFF3DD598),
                shape: RoundedRectangleBorder(
                  side: BorderSide(
                      color: Colors.transparent,
                      width: 1,
                      style: BorderStyle.solid),
                  borderRadius: BorderRadius.circular(60),
                ),
              ),
              child: FlatButton(
                onPressed: () {
                  startTimer(0);
                  _scrollController.animateTo(
                      _scrollController.position.minScrollExtent,
                      duration: Duration(seconds: 1),
                      curve: Curves.fastOutSlowIn);
                },
                child: Row(
                  children: [
                    Expanded(
                      child: Align(
                        alignment: Alignment(1.70, 0.00),
                        child: Text(
                          this.widget.loc.translate('New Post'),
                          style: TextStyle(
                            fontSize: ScreenUtil().setSp(16),
                            color: Colors.white,
                            fontFamily: 'Rubik',
                          ),
                        ),
                      ),
                    ),
                    Expanded(
                      child: Row(
                        children: [
                          Container(
                            width: ScreenUtil().setWidth(90),
                            child: Icon(
                              Icons.arrow_forward,
                              size: ScreenUtil().setWidth(25),
                              color: Colors.white,
                            ),
                          ),
                        ],
                      ),
                    ),
                  ],
                ),
              ),
            ),
          ),
        ),
      ],
    );
  }

  _buildDateField() {
    final format = DateFormat("dd/MM/yyyy");
    final TextEditingController controller = TextEditingController();
    final now = DateTime.now();

    final nextYear = new DateTime(
      now.year,
      now.month,
      now.day,
    );
    return Column(
      children: [
        Container(
          decoration: BoxDecoration(
            border: Border(
              bottom: BorderSide(
                width: 15,
                color: Color(0xffE8ECEF),
              ),
            ),
          ),
        ),
        Container(
          color: Colors.white,
          height: ScreenUtil().setHeight(50),
          width: ScreenUtil().screenWidth,
          alignment: Alignment.center,
          child: SizedBox(
            height: ScreenUtil().setHeight(40),
            width: ScreenUtil().screenWidth - ScreenUtil().setWidth(30),
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Flexible(
                  flex: 8,
                  child: Container(
                    decoration: ShapeDecoration(
                        color: Color(0xffE8ECEF),
                        shape: RoundedRectangleBorder(
                          side: BorderSide(
                              color: Colors.transparent,
                              width: 1,
                              style: BorderStyle.solid),
                          borderRadius: BorderRadius.circular(7),
                        )),
                    child: DateTimeField(
                      textAlign: TextAlign.center,
                      readOnly: true,
                      onChanged: (value) {
                        setState(
                          () {
                            selectedValue = value.toString();
                            date = DateFormat("dd/MM/yyyy").format(value);
                            // "${value.day}/${value.month}/${value.year}";
                          },
                        );
                        getPostsByFilter();
                      },
                      controller: controller,
                      format: format,
                      onShowPicker: (context, currentValue) {
                        return showDatePicker(
                            context: context,
                            firstDate: lastDate,
                            initialDate: currentValue ?? DateTime.now(),
                            lastDate: nextYear);
                      },
                      decoration: new InputDecoration(
                          prefixIcon: Icon(
                            Icons.filter_list_rounded,
                            color: Color(0xFF083356),
                          ),
                          labelText: flagFilter
                              ? date
                              : this.widget.loc.translate("filter..."),
                          labelStyle: TextStyle(
                            color: Color(0xFF083356),
                          ),
                          border:
                              OutlineInputBorder(borderSide: BorderSide.none)),
                    ),
                  ),
                ),
                Flexible(
                    flex: 1,
                    child: Container(
                      // color: Colors.red,
                      child: IconButton(
                        padding: const EdgeInsets.all(0.0),
                        onPressed: () => {
                          setState(() =>
                              {flagFilter = false, postsListFilter = postsList})
                        },
                        icon: Icon(Icons.autorenew_rounded),
                        // color: Colors.grey[600],
                        color: Color(0xFF083356),
                      ),
                    )),
              ],
            ),
          ),
        ),
        Container(
          decoration: BoxDecoration(
            border: Border(
              bottom: BorderSide(
                width: 15,
                color: Color(0xffE8ECEF),
              ),
            ),
          ),
        ),
      ],
    );
  }
}
