import 'package:feed_plugin/models/poll_vote_model.dart';
import 'package:feed_plugin/pages/user_image_page.dart';
import 'package:feed_plugin/repo/feed_repository.dart';
import 'package:feed_plugin/service/http_service.dart';
import 'package:feed_plugin/widgets/posts_list_view.dart';
import 'package:flutter/services.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:flutter_screenutil/screenutil_init.dart';
import 'package:feed_plugin/models/post_model.dart';
import 'package:feed_plugin/models/report_sub_type_model.dart';
import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/models/poll_option_model.dart';

import 'package:feed_plugin/widgets/loadingButtonIndicator.dart';
import 'package:feed_plugin/widgets/post.dart';

class UserPost extends StatefulWidget {
  const UserPost({
    Key key,
    @required this.userData,
    @required this.currentUser,
    @required this.userPosts,
    @required this.pollOptionsList,
    @required this.pollVotesList,
    @required this.loc,
  }) : super(key: key);

  final UserModel userData;
  final UserModel currentUser;
  final List<PostModel> userPosts;
  final List<PollOptionModel> pollOptionsList;
  final List<PollVoteModel> pollVotesList;

  final loc;

  @override
  _UserPostState createState() => _UserPostState();
}

class _UserPostState extends State<UserPost> {
  HttpService httpService;
  FeedRepository feedRepository;
  var _scrollController = ScrollController();
  double defaultScreenWidth = 375.0;
  double defaultScreenHeight = 812.0;
  List<PostModel> postsList = [];
  int likeId;
  int dislikeId;
  int saveId;

  final int increment = 10;

  @override
  void initState() {
    _scrollController.addListener(_onScroll);
    SystemChrome.setPreferredOrientations([
      DeviceOrientation.portraitDown,
      DeviceOrientation.portraitUp,
    ]);
    httpService = HttpService("gogog");
    feedRepository = FeedRepository(httpService);
    super.initState();
  }

  void _onScroll() {
    if (_scrollController.position.pixels ==
        _scrollController.position.maxScrollExtent) {
      // getPosts();
    }
  }

  Future<List<PostModel>> getPosts() async {
    await getPostsReports();
    postsList =
        await feedRepository.fetchPostsByUserId(this.widget.userData.id);

    return postsList;
  }

  Future getPostsReports() async {
    List<ReportSubTypeModel> reportsSubTypeList =
        await feedRepository.fetchAllSubType();
    for (var i = 0; i < reportsSubTypeList.length; i++) {
      if (likeId == null || dislikeId == null || saveId == null) {
        if (reportsSubTypeList[i].type == "Like") {
          likeId = reportsSubTypeList[i].id;
        } else if (reportsSubTypeList[i].type == "Dislike") {
          dislikeId = reportsSubTypeList[i].id;
        } else if (reportsSubTypeList[i].type == "Save") {
          saveId = reportsSubTypeList[i].id;
        }
      } else {
        break;
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    var agentName = this.widget.userData.lastName != null &&
            this.widget.userData.lastName != "null"
        ? (this.widget.userData.firstName).toString() +
            " " +
            (this.widget.userData.lastName).toString()
        : (this.widget.userData.firstName).toString();
    return Directionality(
      textDirection: TextDirection.ltr,
      child: ScreenUtilInit(
        designSize: Size(defaultScreenWidth, defaultScreenHeight),
        allowFontScaling: false,
        builder: () => Scaffold(
          appBar: PreferredSize(
            preferredSize: Size.fromHeight(70.0),
            child: AppBar(
              backgroundColor: Color(0xFF083356),
              leading: Padding(
                padding: EdgeInsets.only(
                  top: ScreenUtil().setWidth(9),
                ),
                child: IconButton(
                  onPressed: () {
                    Navigator.pop(context);
                  },
                  icon: Icon(Icons.arrow_back, color: Colors.white),
                ),
              ),
              title: Padding(
                padding: EdgeInsets.only(
                    left: ScreenUtil().setWidth(10),
                    top: ScreenUtil().setWidth(9)),
                child: Text(
                  agentName.toString() + " post",
                  style: TextStyle(color: Colors.white),
                ),
              ),
            ),
          ),
          body: Directionality(
            textDirection: TextDirection.ltr,
            child: Stack(
              children: [
                RefreshIndicator(
                  onRefresh: () {
                    return getPosts();
                  },
                  child: ListView(
                    controller: _scrollController,
                    children: [
                      _buildProfile(this.widget.userData),
                      _buildDetails(),
                      Container(
                        margin: EdgeInsets.only(top: ScreenUtil().setHeight(2)),
                      ),
                      PostsListView(
                        postsList: this.widget.userPosts,
                        pollOptionsList: this.widget.pollOptionsList,
                        currentUser: this.widget.currentUser,
                        pollVotesList: this.widget.pollVotesList,
                        loc: this.widget.loc,
                      ),
                    ],
                  ),
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }

  _buildDetails() {
    return Container(
      color: Colors.white,
      padding: EdgeInsets.only(bottom: ScreenUtil().setHeight(5)),
      child: Row(
        children: [
          Expanded(
              child: Column(
            children: [
              Text(
                this.widget.userPosts.length.toString(),
                style: TextStyle(fontWeight: FontWeight.bold),
              ),
              Text(this.widget.loc.translate("Posts")),
            ],
          )),
          Expanded(
            child: Column(
              children: [
                Text(
                  "100K",
                  style: TextStyle(fontWeight: FontWeight.bold),
                ),
                Text(this.widget.loc.translate("Followers")),
              ],
            ),
          ),
          Expanded(
            child: Column(
              children: [
                Text(
                  "397",
                  style: TextStyle(fontWeight: FontWeight.bold),
                ),
                Text(this.widget.loc.translate("Following")),
              ],
            ),
          )
        ],
      ),
    );
  }

  _buildProfile(currentUser) {
    return Container(
      color: Colors.white,
      child: Padding(
        padding: EdgeInsets.only(
          left: ScreenUtil().setHeight(17),
          top: ScreenUtil().setHeight(20),
          bottom: ScreenUtil().setHeight(15),
        ),
        child: Row(
          children: [
            Column(
              children: [
                Container(
                  margin: EdgeInsets.only(
                    right: ScreenUtil().setWidth(10),
                  ),
                  child: currentUser.profileImg == null ||
                          currentUser.profileImg == "" ||
                          currentUser.profileImg == "null"
                      ? ClipOval(
                          child: Material(
                            color: Color(0xffE8ECEF),
                            child: SizedBox(
                              width: ScreenUtil().setWidth(49),
                              height: ScreenUtil().setHeight(50),
                              child: Center(
                                child: Text(
                                  currentUser.firstName != null &&
                                          currentUser.firstName != "" &&
                                          currentUser.lastName != null &&
                                          currentUser.lastName != ""
                                      ? currentUser.firstName.substring(0, 1) +
                                          currentUser.lastName.substring(0, 1)
                                      : (currentUser.firstName == null ||
                                                  currentUser.firstName ==
                                                      "") &&
                                              currentUser.lastName != null &&
                                              currentUser.lastName != ""
                                          ? currentUser.lastName.substring(0, 1)
                                          : (currentUser.lastName == null ||
                                                      currentUser.lastName ==
                                                          "") &&
                                                  currentUser.firstName !=
                                                      null &&
                                                  currentUser.firstName != ""
                                              ? currentUser.firstName
                                                  .substring(0, 1)
                                              : "",
                                  style: TextStyle(
                                    color: Color(0xFF083356),
                                    fontSize: ScreenUtil().setSp(15),
                                  ),
                                ),
                              ),
                            ),
                          ),
                        )
                      : GestureDetector(
                          onTap: () {
                            Navigator.push(
                              context,
                              MaterialPageRoute(
                                builder: (context) => UserImagePage(
                                  userData: this.widget.userData,
                                ),
                              ),
                            );
                          },
                          child: ClipOval(
                            child: Image.network(
                              currentUser.profileImg,
                              width: ScreenUtil().setWidth(49),
                              height: ScreenUtil().setHeight(50),
                              fit: BoxFit.cover,
                            ),
                          ),
                        ),
                ),
              ],
            ),
            Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Container(
                  width: ScreenUtil().screenWidth - ScreenUtil().setWidth(163),
                  child: Text(
                    currentUser.lastName != null &&
                            currentUser.lastName != "null"
                        ? currentUser.firstName + " " + currentUser.lastName
                        : currentUser.firstName,
                    textAlign: TextAlign.left,
                    maxLines: 1,
                    style: TextStyle(
                      fontWeight: FontWeight.w500,
                      color: Colors.black,
                      fontSize: ScreenUtil().setSp(17),
                      fontFamily: 'Rubik',
                    ),
                  ),
                ),
                Container(
                  // width: ScreenUtil().screenWidth - ScreenUtil().setWidth(165),
                  child: Text(
                    currentUser.about != null && currentUser.about != "null"?
                    currentUser.about: "",
                    textAlign: TextAlign.left,
                    maxLines: 1,
                    style: TextStyle(
                      fontWeight: FontWeight.normal,
                      color: Colors.black.withOpacity(0.4),
                      fontSize: ScreenUtil().setSp(15),
                      fontFamily: "Rubik",
                    ),
                  ),
                ),
              ],
            ),
          ],
        ),
      ),
    );
  }
}
